# Generated by roxygen2: do not edit by hand

export(wdi_get)
export(wdi_get_entities)
export(wdi_get_income_levels)
export(wdi_get_indicators)
export(wdi_get_languages)
export(wdi_get_lending_types)
export(wdi_get_regions)
export(wdi_get_sources)
export(wdi_get_topics)
export(wdi_search)
import(dplyr)
import(httr2)
import(jsonlite)
import(tibble)
importFrom(purrr,map)
importFrom(purrr,map_df)
importFrom(purrr,reduce)
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(rlang,eval_tidy)
importFrom(rlang,parse_expr)
importFrom(tidyr,nest)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unnest)
importFrom(tidyr,unnest_longer)
importFrom(tidyr,unnest_wider)
