#' @keywords internal
#' @import httr2
#' @import dplyr
#' @import tibble
#' @import jsonlite
"_PACKAGE"

## usethis namespace: start
#' @importFrom purrr map map_df reduce
#' @importFrom tidyr unnest nest pivot_wider unnest_wider unnest_longer
#' @importFrom rlang parse_expr eval_tidy .data %||%
## usethis namespace: end
NULL
